<?php
/**
 * The template for displaying Author Archive pages
 *
 * Used to display archive-type pages for posts by an author.
 *
 * @link http://codex.wordpress.org/Template_Hierarchy
 *
 * @package WordPress
 * @subpackage Benco_Theme
 * @since Benco 1.0
 */

$benco_opt = get_option( 'benco_opt' );

get_header();

$benco_bloglayout = 'sidebar';
if(isset($benco_opt['blog_layout']) && $benco_opt['blog_layout']!=''){
	$benco_bloglayout = $benco_opt['blog_layout'];
}
if(isset($_GET['layout']) && $_GET['layout']!=''){
	$benco_bloglayout = $_GET['layout'];
}
$benco_blogsidebar = 'right';
if(isset($benco_opt['sidebarblog_pos']) && $benco_opt['sidebarblog_pos']!=''){
	$benco_blogsidebar = $benco_opt['sidebarblog_pos'];
}
if(isset($_GET['sidebar']) && $_GET['sidebar']!=''){
	$benco_blogsidebar = $_GET['sidebar'];
}
if ( !is_active_sidebar( 'sidebar-1' ) )  {
	$benco_bloglayout = 'nosidebar';
}
switch($benco_bloglayout) {
	case 'sidebar':
		$benco_blogclass = 'blog-sidebar';
		$benco_blogcolclass = 9;
		Benco_Class::benco_post_thumbnail_size('benco-category-thumb');
		break;
	case 'largeimage':
		$benco_blogclass = 'blog-large';
		$benco_blogcolclass = 9;
		$benco_postthumb = '';
		break;
	default:
		$benco_blogclass = 'blog-nosidebar';
		$benco_blogcolclass = 12;
		$benco_blogsidebar = 'none';
		Benco_Class::benco_post_thumbnail_size('benco-post-thumb');
}
?>
<div class="main-container">
	<div class="title-breadcrumbs <?php if(isset($benco_opt['page_banner']['url']) && ($benco_opt['page_banner']['url'])!=''){ echo 'has-page-banner'; } ?>">
		<?php if(isset($benco_opt['page_banner']['url']) && ($benco_opt['page_banner']['url'])!=''){ ?>
			<div class="page-banner">
				<img src="<?php echo esc_url($benco_opt['page_banner']['url']); ?>" alt=" " />
			</div>
		<?php } ?>
		<div class="title-breadcrumbs-inner">
			<div class="container">
				<header class="entry-header">
					<h1 class="entry-title"><?php if(isset($benco_opt)) { echo esc_html($benco_opt['blog_header_text']); } else { esc_html_e('Blog', 'benco');}  ?></h1>
				</header> 
				<?php Benco_Class::benco_breadcrumb(); ?>
			</div>
		</div>
	</div>
	<div class="container">
		<div class="row">

			<?php if($benco_blogsidebar=='left') : ?>
				<?php get_sidebar(); ?>
			<?php endif; ?>

			<div class="col-12 <?php echo 'col-lg-'.$benco_blogcolclass; ?>">
				<div class="page-content blog-page <?php echo esc_attr($benco_blogclass); if($benco_blogsidebar=='left') {echo ' left-sidebar'; } if($benco_blogsidebar=='right') {echo ' right-sidebar'; } ?>">
					<?php if ( have_posts() ) : ?>

						<?php
							/* Queue the first post, that way we know
							 * what author we're dealing with (if that is the case).
							 *
							 * We reset this later so we can run the loop
							 * properly with a call to rewind_posts().
							 */
							the_post();
						?>

						<header class="archive-header">
							<h1 class="archive-title"><?php printf( esc_html__( 'Author Archives: %s', 'benco' ), '<span class="vcard"><a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( "ID" ) ) ) . '" title="' . esc_attr( get_the_author() ) . '" rel="me">' . get_the_author() . '</a></span>' ); ?></h1>
						</header><!-- .archive-header -->

						<?php
							/* Since we called the_post() above, we need to
							 * rewind the loop back to the beginning that way
							 * we can run the loop properly, in full.
							 */
							rewind_posts();
						?>

						<?php
						// If a user has filled out their description, show a bio on their entries.
						if ( get_the_author_meta( 'description' ) ) : ?>
						<div class="author-info archives">
							<div class="author-avatar">
								<?php
								/**
								 * Filter the author bio avatar size.
								 *
								 * @since Benco 1.0
								 *
								 * @param int $size The height and width of the avatar in pixels.
								 */
								$author_bio_avatar_size = apply_filters( 'benco_author_bio_avatar_size', 68 );
								echo get_avatar( get_the_author_meta( 'user_email' ), $author_bio_avatar_size );
								?>
							</div><!-- .author-avatar -->
							<div class="author-description">
								<h2><?php printf( esc_html__( 'About %s', 'benco' ), get_the_author() ); ?></h2>
								<p><?php the_author_meta( 'description' ); ?></p>
							</div><!-- .author-description	-->
						</div><!-- .author-info -->
						<?php endif; ?>

						<?php /* Start the Loop */ ?>
						<?php while ( have_posts() ) : the_post(); ?>
							<?php get_template_part( 'content', get_post_format() ); ?>
						<?php endwhile; ?>
						
						<?php Benco_Class::benco_pagination(); ?>

					<?php else : ?>
						<?php get_template_part( 'content', 'none' ); ?>
					<?php endif; ?>
				</div>
			</div>
			
			<?php if( $benco_blogsidebar=='right') : ?>
				<?php get_sidebar(); ?>
			<?php endif; ?>
			
		</div>
		
	</div>
 	<!-- brand logo -->
 	<?php 
 		if(isset($benco_opt['inner_brand']) && function_exists('benco_brands_shortcode') && shortcode_exists( 'ourbrands' ) ){
 			if($benco_opt['inner_brand'] && isset($benco_opt['brand_logos'][0]) && $benco_opt['brand_logos'][0]['thumb']!=null) { ?>
 				<div class="inner-brands">
 					<div class="container">
 						<?php if(isset($benco_opt['inner_brand_title']) && $benco_opt['inner_brand_title']!=''){ ?>
 							<div class="title">
 								<h3><?php echo esc_html( $benco_opt['inner_brand_title'] ); ?></h3>
 							</div>
 						<?php } ?>
 						<?php echo do_shortcode('[ourbrands]'); ?>
 					</div>
 				</div>
 				
 			<?php }
 		}
 	?>
 	<!-- end brand logo --> 
</div>
<?php get_footer(); ?>