<?php
/**
 * The main template file
 *
 * This is the most generic template file in a WordPress theme
 * and one of the two required files for a theme (the other being style.css).
 * It is used to display a page when nothing more specific matches a query.
 * For example, it puts together the home page when no home.php file exists.
 *
 * @link http://codex.wordpress.org/Template_Hierarchy
 *
 * @package WordPress
 * @subpackage Benco_Theme
 * @since Benco 1.0
 */

$benco_opt = get_option( 'benco_opt' );

get_header();

$benco_bloglayout = 'sidebar';

if(isset($benco_opt['blog_layout']) && $benco_opt['blog_layout']!=''){
	$benco_bloglayout = $benco_opt['blog_layout'];
}
if(isset($_GET['layout']) && $_GET['layout']!=''){
	$benco_bloglayout = $_GET['layout'];
}
$benco_blogsidebar = 'right';
if(isset($benco_opt['sidebarblog_pos']) && $benco_opt['sidebarblog_pos']!=''){
	$benco_blogsidebar = $benco_opt['sidebarblog_pos'];
}
if(isset($_GET['sidebar']) && $_GET['sidebar']!=''){
	$benco_blogsidebar = $_GET['sidebar'];
}
if ( !is_active_sidebar( 'sidebar-1' ) )  {
	$benco_bloglayout = 'nosidebar';
}
switch($benco_bloglayout) {
	case 'sidebar':
		$benco_blogclass = 'blog-sidebar';
		$benco_blogcolclass = 9;
		Benco_Class::benco_post_thumbnail_size('benco-category-thumb');
		break;
	case 'largeimage':
		$benco_blogclass = 'blog-large';
		$benco_blogcolclass = 9;
		Benco_Class::benco_post_thumbnail_size('benco-category-thumb');
		break;
	case 'grid':
		$benco_blogclass = 'grid';
		$benco_blogcolclass = 9;
		Benco_Class::benco_post_thumbnail_size('benco-category-thumb');
		break;
	default:
		$benco_blogclass = 'blog-nosidebar';
		$benco_blogcolclass = 12;
		$benco_blogsidebar = 'none';
		Benco_Class::benco_post_thumbnail_size('benco-post-thumbwide');
}
?>

<div class="main-container">
	<div class="page-content">
		<div class="title-breadcrumbs <?php if(isset($benco_opt['page_banner']['url']) && ($benco_opt['page_banner']['url'])!=''){ echo 'has-page-banner'; } ?>">
			<?php if(isset($benco_opt['page_banner']['url']) && ($benco_opt['page_banner']['url'])!=''){ ?>
				<div class="page-banner">
					<img src="<?php echo esc_url($benco_opt['page_banner']['url']); ?>" alt="page banner" />
				</div>
			<?php } ?>
			<div class="title-breadcrumbs-inner">
				<div class="container">
					<header class="entry-header">
						<h1 class="entry-title"><?php if(isset($benco_opt)) { echo esc_html($benco_opt['blog_header_text']); } else { esc_html_e('Blog', 'benco');}  ?></h1>
					</header> 
					<?php Benco_Class::benco_breadcrumb(); ?>
				</div>
			</div>
		</div>
		<div class="container">
			<div class="row">

				<?php if($benco_blogsidebar=='left') : ?>
					<?php get_sidebar(); ?>
				<?php endif; ?>

				<div class="col-12 <?php echo 'col-lg-'.$benco_blogcolclass; ?>">
				
					<div class="blog-page blogs <?php echo esc_attr($benco_blogclass); if($benco_blogsidebar=='left') {echo ' left-sidebar'; } if($benco_blogsidebar=='right') {echo ' right-sidebar'; } ?>">
						<?php if ( have_posts() ) : ?>

							<?php /* Start the Loop */ ?>
							<?php while ( have_posts() ) : the_post(); ?>
								
								<?php get_template_part( 'content', get_post_format() ); ?>
								
							<?php endwhile; ?>

							<?php Benco_Class::benco_pagination(); ?>
							
						<?php else : ?>

							<article id="post-0" class="post no-results not-found">

							<?php if ( current_user_can( 'edit_posts' ) ) :
								// Show a different message to a logged-in user who can add posts.
							?>
								<header class="entry-header">
									<h1 class="entry-title"><?php esc_html_e( 'No posts to display', 'benco' ); ?></h1>
								</header>

								<div class="entry-content">
									<p><?php printf( wp_kses(__( 'Ready to publish your first post? <a href="%s">Get started here</a>.', 'benco' ), array('a'=>array('href'=>array()))), admin_url( 'post-new.php' ) ); ?></p>
								</div><!-- .entry-content -->

							<?php else :
								// Show the default message to everyone else.
							?>
								<header class="entry-header">
									<h1 class="entry-title"><?php esc_html_e( 'Nothing Found', 'benco' ); ?></h1>
								</header>

								<div class="entry-content">
									<p><?php esc_html_e( 'Apologies, but no results were found. Perhaps searching will help find a related post.', 'benco' ); ?></p>
									<?php get_search_form(); ?>
								</div><!-- .entry-content -->
							<?php endif; // end current_user_can() check ?>

							</article><!-- #post-0 -->

						<?php endif; // end have_posts() check ?>
					</div>
					
				</div>

				<?php if( $benco_blogsidebar=='right') : ?>
					<?php get_sidebar(); ?>
				<?php endif; ?>
				
			</div>
		</div>
	</div>
	<!-- brand logo -->
	<?php 
		if(isset($benco_opt['inner_brand']) && function_exists('benco_brands_shortcode') && shortcode_exists( 'ourbrands' ) ){
			if($benco_opt['inner_brand'] && isset($benco_opt['brand_logos'][0]) && $benco_opt['brand_logos'][0]['thumb']!=null) { ?>
				<div class="inner-brands">
					<div class="container">
						<?php if(isset($benco_opt['inner_brand_title']) && $benco_opt['inner_brand_title']!=''){ ?>
							<div class="title">
								<h3><?php echo esc_html( $benco_opt['inner_brand_title'] ); ?></h3>
							</div>
						<?php } ?>
						<?php echo do_shortcode('[ourbrands]'); ?>
					</div>
				</div>
				
			<?php }
		}
	?>
	<!-- end brand logo --> 
</div>
<?php get_footer(); ?>