<?php
/**
 * The template for displaying product content within loops
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/content-product.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see     https://docs.woocommerce.com/document/template-structure/
 * @author  WooThemes
 * @package WooCommerce/Templates
 * @version 3.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

global $product, $woocommerce_loop;

$benco_opt = get_option( 'benco_opt' );

$benco_viewmode = Benco_Class::benco_show_view_mode();

// Ensure visibility
if ( ! $product || ! $product->is_visible() )
	return;


// Extra post classes
$classes = array();

$count   = $product->get_rating_count();

$benco_shopclass = Benco_Class::benco_shop_class('');

$colwidth = 3;

if($benco_shopclass=='shop-fullwidth') {
	if(isset($benco_opt)){
		$woocommerce_loop['columns'] = $benco_opt['product_per_row_fw'];
		if($woocommerce_loop['columns'] > 0){
			$colwidth = round(12/$woocommerce_loop['columns']);
		}
	}
	$classes[] = ' item-col col-6 col-md-4 col-lg-'.$colwidth ;
} else {
	if(isset($benco_opt)){
		$woocommerce_loop['columns'] = $benco_opt['product_per_row'];
		if($woocommerce_loop['columns'] > 0){
			$colwidth = round(12/$woocommerce_loop['columns']);
		}
	}
	$classes[] = ' item-col col-sm-6 col-md-4 col-lg-'.$colwidth ;
}
?>

<div <?php post_class( $classes ); ?>>
	<div class="product-wrapper gridview">
		<div class="list-col4">
			<div class="product-image">
				<?php do_action( 'woocommerce_before_shop_loop_item' ); ?>
				
				<?php do_action( 'woocommerce_before_shop_loop_item_title' ); ?>
					
				<?php do_action( 'woocommerce_after_shop_loop_item' ); ?>
				
				<?php if ($count) { ?>
					<div class="product-rating">
						<?php do_action( 'woocommerce_after_shop_loop_item_title' ); ?>
						<!-- hook rating -->
					</div>
				<?php } ?>
				<!-- end rating -->

			</div>
			<ul class="actions">
				<li class="add-to-compare">
					<?php if( class_exists( 'YITH_Woocompare' ) ) {
						echo do_shortcode('[yith_compare_button]');
					} ?>
				</li>
				<li class="add-to-wishlist"> 
					<?php if ( class_exists( 'YITH_WCWL' ) ) {
						echo preg_replace("/<img[^>]+\>/i", " ", do_shortcode('[yith_wcwl_add_to_wishlist]'));
					} ?>
				</li>
				<li class="quickviewbtn">
					<a class="detail-link quickview fa fa-external-link" data-quick-id="<?php the_ID();?>" href="<?php the_permalink(); ?>" title="<?php the_title(); ?>"><?php esc_html_e('Quick View', 'benco');?></a>
				</li>
				<li class="add-to-cart">
					<?php echo do_shortcode('[add_to_cart id="'.$product->get_id().'"]') ?>
				</li>
			</ul>
			<!-- end action -->
		</div>
		<div class="list-col8">
			<div class="product-name">
				<?php do_action( 'woocommerce_shop_loop_item_title' ); ?>
				<a href="<?php the_permalink(); ?>"><?php the_title(); ?></a>
			</div>
			<!-- end name -->
			
			<?php if ( $product->get_price() != '' )  { ?>
				<div class="price-box">
					<?php echo ''.$product->get_price_html(); ?>
				</div>
			<?php } ?>
			<!-- end price -->
		</div>
	</div>

	<div class="product-wrapper listview">
		<div class="list-col4 <?php if($benco_viewmode=='list-view'){ echo ' col-12 col-md-4';} ?>">
			<div class="product-image">
				<?php do_action( 'woocommerce_before_shop_loop_item' ); ?>
				
				<?php do_action( 'woocommerce_before_shop_loop_item_title' ); ?>
					
				<?php do_action( 'woocommerce_after_shop_loop_item' ); ?>
			</div>
		</div>
		<div class="list-col8 <?php if($benco_viewmode=='list-view'){ echo ' col-12 col-md-8';} ?>">

			<div class="product-name">
				<?php do_action( 'woocommerce_shop_loop_item_title' ); ?>
				<a href="<?php the_permalink(); ?>"><?php the_title(); ?></a>
			</div>
			<!-- end name -->

			<?php if ( $product->get_price() != '' )  { ?>
				<div class="price-box">
					<?php echo ''.$product->get_price_html(); ?>
				</div>
			<?php } ?>
			<!-- end price -->
			
			<?php if ($count) { ?>
				<div class="product-rating">
					<?php do_action( 'woocommerce_after_shop_loop_item_title' ); ?>
					<!-- hook rating -->
				</div>
			<?php } ?>
			<!-- end rating -->
			
			<?php if ( has_excerpt() ) { ?>
				<div class="product-desc">
					<?php the_excerpt(); ?>
				</div>
			<?php } ?>
			<!-- end desc -->

			<div class="product-button">
				<div class="add-to-cart">
					<?php echo do_shortcode('[add_to_cart id="'.$product->get_id().'"]') ?>
				</div>
				
				<ul class="actions">
					<li class="add-to-compare">
						<?php if( class_exists( 'YITH_Woocompare' ) ) {
							echo do_shortcode('[yith_compare_button]');
						} ?>
					</li>
					<li class="add-to-wishlist"> 
						<?php if ( class_exists( 'YITH_WCWL' ) ) {
							echo preg_replace("/<img[^>]+\>/i", " ", do_shortcode('[yith_wcwl_add_to_wishlist]'));
						} ?>
					</li>
					<li class="quickviewbtn">
						<a class="detail-link quickview fa fa-external-link" data-quick-id="<?php the_ID();?>" href="<?php the_permalink(); ?>" title="<?php the_title(); ?>"><?php esc_html_e('Quick View', 'benco');?></a>
					</li>
				</ul>
			</div>
			<!-- end button -->
		</div>
	</div>
</div>